@@ -2,10 +2,10 @@
 
 Context : SRP
 Module  : SRPConstants.py
-Version : 1.13.1
+Version : 1.14.0
 Status  : approved
 Author  : Stefano Covino, Daniele Malesani
-Date    : 22/09/2011
+Date    : 28/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.merate.mi.astro.it/~covino
 Purpose : Collection of constants, functions and classes for SRP.
@@ -82,6 +82,7 @@ History : (20/05/2003) First version.
         : (02/08/2011) Image filter extension.
         : (18/08/2011) Gemini GMOS parameters.
         : (22/09/2011) Ascii spectra extension.
+        : (28/02/2012) TNG Dolores spec and pol entries.
 """
 
 import os
@@ -223,6 +224,44 @@ OBJCAT
 OBS-TYPE
 FLT_ID
 """
+SRPTNGDOLORESSPEC = "TNGDOLORESSPEC"
+TNGDOLORESSPEC  = """NAXIS1
+NAXIS2
+INSTRUME
+RA-DEG
+DEC-DEG
+AIRMASS
+DATE-OBS
+EXPSTART
+EXPTIME
+OBJCAT
+OBS-TYPE
+FLT_ID
+GRM_ID
+SLT_ID
+LMP_ID
+"""
+SRPTNGDOLORESPOL = "TNGDOLORESPOL"
+TNGDOLORESPOL  = """NAXIS1
+NAXIS2
+INSTRUME
+RA-DEG
+DEC-DEG
+AIRMASS
+DATE-OBS
+EXPSTART
+EXPTIME
+OBJCAT
+OBS-TYPE
+FLT_ID
+GRM_ID
+SLT_ID
+PSLDR_ID
+RTRY1_ID
+RTRY2_ID
+POSANG
+PARANG
+"""
 SRPTNGNICSIMA = "TNGNICSIMA"
 TNGNICSIMA   = """NAXIS
 NAXIS1
@@ -524,12 +563,12 @@ MJD-OBS
 """
 
 
-SRPPREKEYDICT = {SRPVLTFORSIMA:VLTFORSIMA, SRPLASCIMA:LASCIMA, SRPTNGDOLORESIMA:TNGDOLORESIMA,
- SRPASIAGOAFOSCIMA:ASIAGOAFOSCIMA, SRPVLTISAACIMA:VLTISAACIMA, SRPVLTFORSSPEC:VLTFORSSPEC,
- SRPNTTEMMIIMA:NTTEMMIIMA, SRPNOTALFOSCIMA:NOTALFOSCIMA, SRPDOSDOSCALTOCAFOSIMA:DOSDOSCALTOCAFOSIMA,
- SRPDANISHDFOSCIMA:DANISHDFOSCIMA, SRPVLTNACOIMA:VLTNACOIMA, SRPTNGNICSIMA:TNGNICSIMA, SRPREMROSSIMA:REMROSSIMA,
- SRPNTTSOFIIMA:NTTSOFIIMA, SRPVLTFORSIPOL:VLTFORSIPOL, SRPVLTXSHOOTER:VLTXSHOOTER, SRPTNGDOLORESSPEC:TNGDOLORESSPEC,
- SRPGEMINIGMOSIMA:GEMINIGMOSIMA}
+SRPPREKEYDICT = {SRPVLTFORSIMA:VLTFORSIMA, SRPLASCIMA:LASCIMA, SRPTNGDOLORESIMA:TNGDOLORESIMA, 
+ SRPTNGDOLORESSPEC:TNGDOLORESSPEC, SRPTNGDOLORESPOL:TNGDOLORESPOL, SRPASIAGOAFOSCIMA:ASIAGOAFOSCIMA, 
+ SRPVLTISAACIMA:VLTISAACIMA, SRPVLTFORSSPEC:VLTFORSSPEC, SRPNTTEMMIIMA:NTTEMMIIMA, SRPNOTALFOSCIMA:NOTALFOSCIMA,
+ SRPDOSDOSCALTOCAFOSIMA:DOSDOSCALTOCAFOSIMA, SRPDANISHDFOSCIMA:DANISHDFOSCIMA, SRPVLTNACOIMA:VLTNACOIMA, 
+ SRPTNGNICSIMA:TNGNICSIMA, SRPREMROSSIMA:REMROSSIMA, SRPNTTSOFIIMA:NTTSOFIIMA, SRPVLTFORSIPOL:VLTFORSIPOL, 
+ SRPVLTXSHOOTER:VLTXSHOOTER, SRPTNGDOLORESSPEC:TNGDOLORESSPEC, SRPGEMINIGMOSIMA:GEMINIGMOSIMA}
 
 
 
