@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : System
-Version : 1.0.1
+Version : 1.0.2
 Author  : Stefano Covino
-Date    : 02/10/2011
+Date    : 05/02/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -12,9 +12,11 @@ Usage   : to be imported
 
 History : (24/08/2011) First named version.
         : (02/10/2011) List of Fits files function.
+        : (05/02/2012) Solid path.
 """
 
 
 
-__all__ = ['ListDirTimeSorted', 'ListOfFitsFiles', 'Pipe', 'Touch', 'Which']
+__all__ = ['ListDirTimeSorted', 'ListOfFitsFiles', 'Pipe', 'SRPPath', 
+            'Touch', 'Which']
 
