@@ -55,18 +55,18 @@ import SRP.stats as stats
 
 
 
-def which(command):
-    percorso = os.getenv("PATH")
-    directories = percorso.split(os.pathsep)
-    for path_dir in directories:
-        real_dir = os.path.expanduser(path_dir)
-        try:
-            lista_dir = os.listdir(real_dir)
-        except OSError:
-            lista_dir = []
-        if os.path.exists(real_dir) and command in lista_dir:
-            return os.path.join(real_dir, command)
-    return None
+#def which(command):
+#    percorso = os.getenv("PATH")
+#    directories = percorso.split(os.pathsep)
+#    for path_dir in directories:
+#        real_dir = os.path.expanduser(path_dir)
+#        try:
+#            lista_dir = os.listdir(real_dir)
+#        except OSError:
+#            lista_dir = []
+#        if os.path.exists(real_dir) and command in lista_dir:
+#            return os.path.join(real_dir, command)
+#    return None
 
 
 
