@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.0.47
+Version : 1.0.53
 Author  : Stefano Covino
-Date    : 28/02/2012
+Date    : 21/05/2012
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -65,6 +65,12 @@ History : (28/09/2010) First named version.
         : (14/02/2012) V. 3.10.4b5.
         : (18/02/2012) V. 3.10.4b6 and SRPSky.
         : (28/02/2012) V. 3.10.4.
+        : (29/02/2012) V. 3.10.5b1.
+        : (05/03/2012) V. 3.10.5b2.
+        : (11/03/2012) V. 3.10.5b3.
+        : (21/03/2012) V. 3.10.5b4.
+        : (20/05/2012) V. 3.10.5b5.
+        : (21/05/2012) V. 3.10.5.
 """
 
 
@@ -79,5 +85,5 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.4'
+__version__ = '3.10.5'
 
